pub struct CommandNext<'a, C>where
C: Command + 'static,{ /* private fields */ }Expand description
Remaining command middleware followed by the final typed handler.
Middleware calls run exactly when it wants processing to
continue. It may validate and short-circuit before that call, or inspect and
transform the result after it completes.
Implementations
Sourceimpl<'a, C> CommandNext<'a, C>where
C: Command + 'static,
impl<'a, C> CommandNext<'a, C>where
C: Command + 'static,
Sourcepub fn run(self, command: C) -> BoxFuture<'a, SoapResult<C::Output>>
pub fn run(self, command: C) -> BoxFuture<'a, SoapResult<C::Output>>
Continues the pipeline with the next middleware or final handler.